package moraxus.server;

import java.io.IOException;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import moraxus.server.storage.AppEngineStorage;
import moraxus.server.storage.Content;
import moraxus.server.storage.MoraxusKey;
import moraxus.server.storage.Storage;
import moraxus.server.user.Authenticator;
import moraxus.server.user.User;

@SuppressWarnings("serial")
public class IdServlet extends HttpServlet {

	public void doGet(HttpServletRequest req, HttpServletResponse resp) throws IOException {
		// Find the path, for instance /content/blog
		String path=req.getPathInfo();
		if(path==null || path.equals("/")){//No ID, get the root
			path="";
		}else{//We have an ID
			path=path.substring(1);
			path=Util.getFormattedPath(path);
		}
		
		//Get the key
		Storage db = Configuration.getStorage();
		MoraxusKey key;
		
		if(path.equals("")){
			key=db.getKeyFromPath("/");
		}else{
			key=new MoraxusKey(path);
		}

		// No key?
		if(key==null){
			OutputWriter.write(resp, HttpServletResponse.SC_BAD_REQUEST, req.getParameter("format"), new OutMessage("error", "no key found"));
			return;
		}
		
		try {
			if(!Util.hasReadAccess(req, key)){
				OutputWriter.write(resp, HttpServletResponse.SC_UNAUTHORIZED, req.getParameter("format"), new OutMessage("error", "forbidden"));
				return;
			}
			
			// Get the object
			Content c=db.getContent(key);	
		
			//Add children references
			c.setChildren(db.getChildrenKeys(key));

			//And print! :-D
			OutputWriter.write(resp, HttpServletResponse.SC_ACCEPTED, req.getParameter("format"), c);
		} catch (Exception e) {
			OutputWriter.write(resp, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, req.getParameter("format"), new OutMessage("error", e.toString()));
		}
	}
}
