package moraxus.server;

import java.io.IOException;
import java.lang.reflect.Type;

import javax.servlet.http.HttpServletResponse;

import moraxus.server.storage.Content;
import moraxus.server.storage.MoraxusKey;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonObject;
import com.google.gson.JsonSerializationContext;
import com.google.gson.JsonSerializer;
import com.thoughtworks.xstream.XStream;

public class OutputWriter {
	public static void write(HttpServletResponse resp, int responseCode, String format, Object object) {
		try {
			// Determine the right format
			if (format == null || format.equals("") || format.equalsIgnoreCase("json"))
				writeJSON(resp, responseCode, object);
			else if (format.equalsIgnoreCase("xml"))
				writeXML(resp, responseCode, object);
			else{//Unknown format! 
				resp.setContentType("text/html");
				resp.setStatus(HttpServletResponse.SC_BAD_REQUEST);
				resp.getWriter().write("Unsupported format: " + format);
			}
		} catch (IOException e) {
			// TODO
		}
	}

	private static void writeJSON(HttpServletResponse resp, int responseCode, Object object) throws IOException {
		Gson gson = new GsonBuilder().registerTypeAdapter(OutMessage.class, new OutMessageSerializer()).create();
		resp.setContentType("text/html");
		resp.setStatus(responseCode);
		resp.getWriter().write(gson.toJson(object));
	}
	
	public static class OutMessageSerializer implements JsonSerializer<OutMessage> {
		public JsonObject serialize(OutMessage src, Type typeOfSrc, JsonSerializationContext context) {
			JsonObject jsonObject=new JsonObject();
			jsonObject.addProperty(src.status, src.message);
			return jsonObject;
		}
	}

	private static void writeXML(HttpServletResponse resp, int responseCode, Object object) throws IOException{
		XStream xstream = new XStream();
		xstream.alias("content", Content.class);
		xstream.alias("key", MoraxusKey.class);
		resp.setContentType("text/html");
		resp.setStatus(responseCode);
		resp.getWriter().write(xstream.toXML(object));
	}

}
