package moraxus.server;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import moraxus.server.storage.Content;
import moraxus.server.storage.MoraxusKey;
import moraxus.server.storage.Storage;
import moraxus.server.user.Authenticator;
import moraxus.server.user.User;

public class Util {
	public static String getFormattedPath(String path) {
		if (path == null)
			path = "/";

		// /content/blog/ to /content/blog
		if (path.lastIndexOf("/") + 1 == path.length())
			path = path.substring(0, path.lastIndexOf("/"));

		if (path.equals(""))
			path = "/";

		return path;
	}

	public static boolean isValidAPIKey(String apiKey) {
		if (apiKey == null || apiKey.equals(""))
			return false;

		// Is it the test key?
		if (apiKey.equals("123456789"))
			return true;

		// Check if it is valid
		Storage db = Configuration.getStorage();
		Map<String, String> map = new HashMap<String, String>();
		map.put("value", apiKey);
		return db.search(null, "API_KEY", map).size() > 0;
	}
	
	public static boolean hasReadAccess(HttpServletRequest req, Content c){
		return hasReadAccess(req, c.getKey());
	}
	
	public static boolean hasReadAccess(HttpServletRequest req, MoraxusKey key){
		Storage db = Configuration.getStorage();
		Content c=db.getContent(key);
		
		// No access?
		if(!c.canPublicRead()){
			Authenticator auth=Configuration.getAuthenticator();
			User user=auth.getCurrentUser(req);
			
			if(user==null){
				return false;
			}
			
			if(!db.hasReadAccess(user.getId(), c.getKey().toString())){
				return false;
			}
		}	
		return true;
	}
	
	public static boolean hasWriteAccess(HttpServletRequest req, Content c){
		return hasWriteAccess(req, c.getKey());
	}
	
	public static boolean hasWriteAccess(HttpServletRequest req, MoraxusKey key){
		Storage db = Configuration.getStorage();
		Content c=db.getContent(key);
		
		// No access?
		if(!c.canPublicWrite()){
			Authenticator auth=Configuration.getAuthenticator();
			User user=auth.getCurrentUser(req);
			
			if(user==null){
				return false;
			}
			
			if(!db.hasWriteAccess(user.getId(), c.getKey().toString())){
				return false;
			}
		}	
		return true;
	}

}
